animate_opa

Function animate_opa 

pub fn animate_opa(obj: impl Widget, from: u8, to: u8, duration_ms: u32)
Fade an object’s main-part opacity from from to to over duration_ms.

Unlike the C++/Zig counterparts this requires the caller to pass the starting opacity explicitly because lv_obj_get_style_opa is a static inline that Rust bindgen doesn’t expose.