ImageDsc

Type Alias ImageDsc 

pub type ImageDsc = lv_image_dsc_t;
Safe re-export of the LVGL image descriptor type, so generated asset modules (e.g. images::badge) can declare their externals without needing to reach into the ove::ffi escape hatch.

Aliased Type

#[repr(C)]
pub struct ImageDsc { pub header: lv_image_header_t, pub data_size: u32, pub data: *const u8, }

Fields

header: lv_image_header_tdata_size: u32data: *const u8