macro_rules! log_err {
($($arg:tt)*) => { ... };
}Expand description
Log an error message with [E] prefix and automatic newline.
Produces the same console output as the C OVE_LOG_ERR macro.
macro_rules! log_err {
($($arg:tt)*) => { ... };
}Log an error message with [E] prefix and automatic newline.
Produces the same console output as the C OVE_LOG_ERR macro.