macro_rules! log_wrn {
($($arg:tt)*) => { ... };
}Expand description
Log a warning message with [W] prefix and automatic newline.
Produces the same console output as the C OVE_LOG_WRN macro.
macro_rules! log_wrn {
($($arg:tt)*) => { ... };
}Log a warning message with [W] prefix and automatic newline.
Produces the same console output as the C OVE_LOG_WRN macro.