work

Macro work 

macro_rules! work {
    ($handler:expr) => { ... };
}
Create a crate::Work item that works in both heap and zero-heap modes.

The handler must be an ove_work_fn (an unsafe extern "C" fn). To avoid writing that yourself, wrap a safe fn() with work_handler!.