write

Function write 

pub fn write(key: &[u8], data: &[u8]) -> Result<()>
Write data under key in NVS. key must be \0-terminated.

If the key already exists its value is replaced.

Errors

Returns Error::NoMemory if storage is full, or another error on failure.