domain_release

Function domain_release 

pub fn domain_release(domain: Domain) -> Result<()>
Decrement the reference count for a peripheral power domain.

When the count reaches zero, the domain hardware is powered off.

Errors

Returns Error::InvalidParam on underflow.