pub fn delay_ms(ms: u32)Expand description
Block the current thread for at least ms milliseconds.
Yields the CPU to other threads for the duration. Prefer crate::Thread::sleep_ms
for thread-level sleeping.
pub fn delay_ms(ms: u32)Block the current thread for at least ms milliseconds.
Yields the CPU to other threads for the duration. Prefer crate::Thread::sleep_ms
for thread-level sleeping.