get_us

Function get_us 

pub fn get_us() -> Result<u64>
Get the current monotonic time in microseconds since an arbitrary epoch.

Errors

Returns an error if the underlying hardware timer is unavailable.