EventGroup

Struct EventGroup 

pub struct EventGroup { /* private fields */ }
Event group — a set of named bits that can be set, cleared, and waited on.

Implementations

Source

impl EventGroup

pub fn new() -> Result<Self>

Create a new event group via heap allocation (only in heap mode).

pub fn set_bits(&self, bits: u32) -> u32

Set bits in the event group. Returns the bits value after setting.

pub fn clear_bits(&self, bits: u32) -> u32

Clear bits in the event group. Returns the bits value before clearing.

pub fn wait_bits( &self, bits: u32, flags: WaitFlags, timeout_ms: u32, ) -> Result<u32>

Wait for the specified bits to be set in the event group.

flags is a combination of WaitFlags::WAIT_ALL and WaitFlags::CLEAR_ON_EXIT. Returns the bits value at the moment the wait condition was satisfied.

Errors

Returns Error::Timeout if the bits are not set within timeout_ms.

pub fn set_bits_from_isr(&self, bits: u32) -> u32

Set bits from an ISR context. Returns the bits value after setting.

pub fn get_bits(&self) -> u32

Get current bits value.