pub struct EventGroup { /* private fields */ }Expand description
Event group — a set of named bits that can be set, cleared, and waited on.
Implementations
Sourceimpl EventGroup
impl EventGroup
Sourcepub fn set_bits(&self, bits: u32) -> u32
pub fn set_bits(&self, bits: u32) -> u32
Set bits in the event group. Returns the bits value after setting.
Sourcepub fn clear_bits(&self, bits: u32) -> u32
pub fn clear_bits(&self, bits: u32) -> u32
Clear bits in the event group. Returns the bits value before clearing.
Sourcepub fn wait_bits(
&self,
bits: u32,
flags: WaitFlags,
timeout_ms: u32,
) -> Result<u32>
pub fn wait_bits( &self, bits: u32, flags: WaitFlags, timeout_ms: u32, ) -> Result<u32>
Wait for the specified bits to be set in the event group.
flags is a combination of WaitFlags::WAIT_ALL and WaitFlags::CLEAR_ON_EXIT.
Returns the bits value at the moment the wait condition was satisfied.
Errors
Returns Error::Timeout if the bits are not set within timeout_ms.
Sourcepub fn set_bits_from_isr(&self, bits: u32) -> u32
pub fn set_bits_from_isr(&self, bits: u32) -> u32
Set bits from an ISR context. Returns the bits value after setting.