pub struct Obj { /* private fields */ }Expand description
Non-owning handle to an LVGL object (lv_obj_t *).
LVGL manages object lifetimes (parent owns children). No Drop.
Copy enables fluent method chaining (self -> Self).
Implementations
Sourceimpl Obj
impl Obj
Sourcepub unsafe fn from_raw(raw: *mut lv_obj_t) -> Self
pub unsafe fn from_raw(raw: *mut lv_obj_t) -> Self
Wrap a raw LVGL object pointer.
Safety
The pointer must be valid and obtained from an LVGL function.
Sourcepub fn child_count(self) -> u32
pub fn child_count(self) -> u32
Get number of children.
Sourcepub fn get_height(self) -> i32
pub fn get_height(self) -> i32
Get current height.
Sourcepub fn set_user_data(self, data: *mut c_void) -> Self
pub fn set_user_data(self, data: *mut c_void) -> Self
Set user data pointer.
Sourcepub fn get_user_data(self) -> *mut c_void
pub fn get_user_data(self) -> *mut c_void
Get user data pointer.
Sourcepub fn set_pos(self, x: i32, y: i32)
pub fn set_pos(self, x: i32, y: i32)
Set the position of the widget (legacy, non-fluent variant).
Sourcepub fn set_style_bg_color(self, color: Color, selector: u32)
pub fn set_style_bg_color(self, color: Color, selector: u32)
Set the background color for the given selector (legacy, non-fluent variant).
Sourcepub fn set_style_text_color(self, color: Color, selector: u32)
pub fn set_style_text_color(self, color: Color, selector: u32)
Set the text color for the given selector (legacy, non-fluent variant).
Sourcepub fn set_style_radius(self, radius: i32, selector: u32)
pub fn set_style_radius(self, radius: i32, selector: u32)
Set the corner radius for the given selector (legacy, non-fluent variant).
Sourcepub fn set_style_text_font(self, font: *const lv_font_t, selector: u32)
pub fn set_style_text_font(self, font: *const lv_font_t, selector: u32)
Set the text font for the given selector (legacy, non-fluent variant).