Style

Struct Style 

pub struct Style { /* private fields */ }
RAII wrapper around lv_style_t. Calls lv_style_reset on drop.

Implementations

Source

impl Style

pub fn new() -> Self

Create and initialize a new LVGL style object.

pub fn as_mut_ptr(&mut self) -> *mut lv_style_t

Return a raw mutable pointer for use with Styleable::add_style.

pub fn bg_color(self, c: Color) -> Self

Set the background color in this style.

pub fn bg_opa(self, opa: u8) -> Self

Set the background opacity in this style (0 = transparent, 255 = opaque).

pub fn radius(self, r: i32) -> Self

Set the corner radius in this style.

pub fn border_color(self, c: Color) -> Self

Set the border color in this style.

pub fn border_width(self, w: i32) -> Self

Set the border width in this style.

pub fn pad_all(self, p: i32) -> Self

Set equal padding on all four sides in this style.

pub fn text_color(self, c: Color) -> Self

Set the text color in this style.

pub fn text_font(self, f: *const lv_font_t) -> Self

Set the text font in this style.