pub fn domain_release(domain: Domain) -> Result<()>
Decrement the reference count for a peripheral power domain.
When the count reaches zero, the domain hardware is powered off.
Returns Error::InvalidParam on underflow.
Error::InvalidParam