pub struct CondVar { /* private fields */ }Expand description
Condition variable.
Implementations
Sourceimpl CondVar
impl CondVar
Sourcepub fn new() -> Result<Self>
pub fn new() -> Result<Self>
Create a new condition variable via heap allocation (only in heap mode).
Sourcepub fn wait(&self, mutex: &Mutex, timeout_ms: u32) -> Result<()>
pub fn wait(&self, mutex: &Mutex, timeout_ms: u32) -> Result<()>
Atomically release mutex and block until signalled or timeout_ms elapses.
On return (successful or not), mutex is re-acquired before this function returns.
Errors
Returns Error::Timeout if neither signal nor
broadcast fires within timeout_ms.